==> estateplat-common-1.2.4-20201113.091216-505-sources.jar: cn/gtmap/estateplat/model/exchange/unidofrmity/QlfQlDyiqBdc.java <==
package cn.gtmap.estateplat.model.exchange.unidofrmity;

import cn.gtmap.estateplat.model.exchange.national.QlfQlDyiq;
import cn.gtmap.estateplat.utils.JaxbStringAdapter;
import cn.gtmap.estateplat.utils.JaxbStringNoNullAdapter;

import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;

public class QlfQlDyiqBdc extends QlfQlDyiq {
    private String dfgydqlrzjzldm;
    private String dfgydqlrzjzlmc;
    private String dfdjlxdm;
    private String dfdjlxmc;
    private String dfqsztdm;
    private String dfqsztmc;
    @XmlAttribute(
            name = "DFGYDQQLRZJZLDM"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDfgydqlrzjzldm() {
        return dfgydqlrzjzldm;
    }

    public void setDfgydqlrzjzldm(String dfgydqlrzjzldm) {
        this.dfgydqlrzjzldm = dfgydqlrzjzldm;
    }
    @XmlAttribute(
            name = "DFGYDQQLRZJZLMC"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDfgydqlrzjzlmc() {
        return dfgydqlrzjzlmc;
    }

    public void setDfgydqlrzjzlmc(String dfgydqlrzjzlmc) {
        this.dfgydqlrzjzlmc = dfgydqlrzjzlmc;
    }

    @XmlAttribute(
            name = "DFDJLXDM"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDfdjlxdm() {
        return dfdjlxdm;
    }

    public void setDfdjlxdm(String dfdjlxdm) {
        this.dfdjlxdm = dfdjlxdm;
    }
    @XmlAttribute(
            name = "DFDJLXMC"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDfdjlxmc() {
        return dfdjlxmc;
    }

    public void setDfdjlxmc(String dfdjlxmc) {
        this.dfdjlxmc = dfdjlxmc;
    }
    @XmlAttribute(
            name = "DFQSZTDM"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDfqsztdm() {
        return dfqsztdm;
    }

    public void setDfqsztdm(String dfqsztdm) {
        this.dfqsztdm = dfqsztdm;
    }
    @XmlAttribute(
            name = "DFQSZTMC"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDfqsztmc() {
        return dfqsztmc;
    }

    public void setDfqsztmc(String dfqsztmc) {
        this.dfqsztmc = dfqsztmc;
    }
}

==> estateplat-common-1.2.4-20201116.060719-507-sources.jar: cn/gtmap/estateplat/model/exchange/unidofrmity/QlfQlDyiqBdc.java <==
package cn.gtmap.estateplat.model.exchange.unidofrmity;

import cn.gtmap.estateplat.model.exchange.national.QlfQlDyiq;
import cn.gtmap.estateplat.utils.JaxbStringAdapter;
import cn.gtmap.estateplat.utils.JaxbStringNoNullAdapter;

import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;

public class QlfQlDyiqBdc extends QlfQlDyiq {
    private String dfgydqlrzjzldm;
    private String dfgydqlrzjzlmc;
    private String dfdjlxdm;
    private String dfdjlxmc;
    private String dfqsztdm;
    private String dfqsztmc;
    @XmlAttribute(
            name = "DFGYDQQLRZJZLDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfgydqlrzjzldm() {
        return dfgydqlrzjzldm;
    }

    public void setDfgydqlrzjzldm(String dfgydqlrzjzldm) {
        this.dfgydqlrzjzldm = dfgydqlrzjzldm;
    }
    @XmlAttribute(
            name = "DFGYDQQLRZJZLMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfgydqlrzjzlmc() {
        return dfgydqlrzjzlmc;
    }

    public void setDfgydqlrzjzlmc(String dfgydqlrzjzlmc) {
        this.dfgydqlrzjzlmc = dfgydqlrzjzlmc;
    }

    @XmlAttribute(
            name = "DFDJLXDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfdjlxdm() {
        return dfdjlxdm;
    }

    public void setDfdjlxdm(String dfdjlxdm) {
        this.dfdjlxdm = dfdjlxdm;
    }
    @XmlAttribute(
            name = "DFDJLXMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfdjlxmc() {
        return dfdjlxmc;
    }

    public void setDfdjlxmc(String dfdjlxmc) {
        this.dfdjlxmc = dfdjlxmc;
    }
    @XmlAttribute(
            name = "DFQSZTDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfqsztdm() {
        return dfqsztdm;
    }

    public void setDfqsztdm(String dfqsztdm) {
        this.dfqsztdm = dfqsztdm;
    }
    @XmlAttribute(
            name = "DFQSZTMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfqsztmc() {
        return dfqsztmc;
    }

    public void setDfqsztmc(String dfqsztmc) {
        this.dfqsztmc = dfqsztmc;
    }
}
